Description Usage Format Value Fields
Class that encapsulates a layer used for dispalying slices of a 3D volume.
1 |
R6Class object.
Object of R6Class with methods for accessing and changing layer properties.
volan object of class NeuroVol supplying the image data
color_mapthe color map
thresholdthe low and high thresholds to determine transparency.
irangethe intensity range of the low and high end of color scale.
viewthe orientation code (e.g. "LPI") describing the display axes.
zero_colthe color assigned to values of 0.
alphathe degree of opacity for the layer (0 = transparent, 1 = opaque)
view_spacethe linkS4class{NeuroSpace} associaed with the view.
value_rangethe full numeric range of the underlying volume
desca short character description of the layer
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.